# Images clipped by coastlines

```julia
    geoid_cpt = grd2cpt("@india_geoid.nc", cmap=:rainbow)
    grdimage("@india_geoid.nc", I=:default, proj=:merc, figsize=16)

    # Then use gmt pscoast to initiate clip path for land
    coast!(region="@india_geoid.nc", res=:low, clip=:land)

    # Now generate topography image w/shading
    gray = makecpt(color=150, range=(-10000,10000), no_bg=:true)
    grdimage!("@india_topo.nc", I=:default, cmap=gray)

    # Finally undo clipping and overlay basemap
    coast!(clip=:end, frame=(annot=10, ticks=5, title="Clipping of Images"))

    # Put a color legend on top of the land mask
    colorbar!(cmap=geoid_cpt, pos=(anchor=:TR, inside=true, length=(10,0.5),
              offset=(0.8,0.25), horizontal=true), xaxis=(annot=5,ticks=1),
              yaxis=(label="m",), shade=true, Vd=1)

    # Add a text paragraph
    t = ["> 90 -10 12p 3i j"
        "@_@%5%Example 17.@%%@_  We first plot the color geoid image"
        "for the entire region, followed by a gray-shaded @#etopo5@#"
        "image that is clipped so it is only visible inside the coastlines."]
    text!(text_record(t), paragraph=true, fill=:white, pen=:thinner, clearance=(round=true,),
          offset=(-0.25,0.25), font=(12,"Times-Roman"), justify=:RB, show=true)
```

See also [`GMT ex17`](https://www.generic-mapping-tools.org/gmt/latest/gallery/ex17.html#example-17)