# Data selection based on geospatial criteria

```julia
    dateline = [180 0; 180 -90];
    point = [147.21667 -42.8 6000]

    R = gmtinfo("@oz_quakes_24.txt", inc=10);
    coast(region=R[1].text[1][3:end], land=:tan, water=:darkblue,
          shore=(:thin,:white), area=500, proj=:Mercator, figsize=14,
          frame=(axes=:WeSn, annot=20, ticks=10, grid=10))
    plot!("@oz_quakes_24.txt", marker=:circle, ms=0.07, fill=:red)
    t = gmtselect("@oz_quakes_24.txt", mask="k/s", 
                  dist2line=(line=dateline, dist="1000k"),
                  dist2pt=(pts=point, dist="3000k"), colinfo=:g, reverse=:l)
    plot!(t, marker=:circle, ms=0.07, fill=:green)

    plot!(point, marker="Ellipse-", ml=(:thick, :white))
    text!(text_record(point, "Hobart"), font=(14,"Helvetica-Bold",:white),
          justify=:LT, offset=(0.25, 0.25))
    plot!(point, MarkerLine=(:fat, :white), marker=:plus, ms=0.4)
    plot!(dateline, pen=(:thick, :white), straight_lines=true, show=true) 
```

See also [`GMT ex24`](https://www.generic-mapping-tools.org/gmt/latest/gallery/ex24.html#example-24)