# Mixing UTM and geographic data sets

```julia
	# Set up a color table
	Kilauea_cpt = makecpt(cmap=:copper, range=(0, 1500))
	# Lay down the UTM topo grid using a 1:160,000 scale
	grdimage("@Kilauea.utm.nc", frame=:none, shade=:default, proj=:linear,
             figscale="1:160000", par=(FORMAT_FLOAT_OUT="%.10g", FONT_ANNOT_PRIMARY=9))
	# Overlay geographic data and coregister by using correct region and gmt("projection with the same scale
	coast!(region="@Kilauea.utm.nc", proj=:UTM5Q, figscale="1:160000",
           res=:full, water=:lightblue, shore=0.5, frame=(axes=:NE, annot="5m", grid="5m"),
           par=(FONT_ANNOT_PRIMARY=12, FORMAT_GEO_MAP="ddd:mmF"))
	text!(text_record([-155.27222 19.43889], "KILAUEA"), font=(12,"Helvetica-Bold"), justify=:CB)
	basemap!(map_scale=(inside=true, anchor=:RB, scale_at_lat="19:23N", fancy=true,
                        length="5k", label="1:160,000", units=true, offset=0.5),
             par=(FONT_LABEL=10, FONT_ANNOT_PRIMARY=9))
	# Annotate in km but append ,000m to annotations to get customized meter labels
	basemap!(region="@Kilauea.utm.nc+Uk", proj=:linear, figscale="1:160",
             frame=(axes=:WSne, annot=5, grid=5, suffix="@:8:000m@::"),
             par=(FONT_ANNOT_PRIMARY=10, MAP_GRID_CROSS_SIZE_PRIMARY=0.25, FONT_LABEL=10), show=1)
```

See also [`GMT ex28`](https://www.generic-mapping-tools.org/gmt/latest/gallery/ex28.html#example-28)