# Spherical triangulation and distance calculations

```julia
    pol, nodes = sphtriangulate("@gshhs_c.txt", voronoi=:v, skip=true, nodes=true)
    # Compute distances in km
    Gtt = sphdistance(pol, region=:global360, inc=1, voronoi=true, nodes=nodes,
          grid=true, dist_unit=:k)
    makecpt(cmap=:hot, range=(0,3500))
    # Make a basic image plot and overlay contours, Voronoi polygons and coastlines
    grdimage(Gtt, proj=(name=:ortho, center=(-140,30)), figsize=16, x_off=2, y_off=5)
    grdcontour!(Gtt, cont=500, annot=(int=1000, labels=(font=(10,:Helvetica,:white),)),
                range=500, labels=(Line=[0 90 203 -10; 175 60 170 -30; -50 30 220 -5],),
                pen=((annot=true, pen=(0.75,:white)), (contour=true, pen=(0.25,:white))) )
    plot!(pol, pen=(0.25, :green, :dotted))
    coast!(shore=1, land=:steelblue, area=(0,1,1),
           frame=(annot=30, grid=30, title="Distances from GSHHG crude coastlines"),
           show=true)
    ```

See also [`GMT ex35`](https://www.generic-mapping-tools.org/gmt/latest/gallery/ex35.html#example-35)